# /* **************************************************************************
#  *                                                                          *
#  *     (C) Copyright Paul Mensonides 2002.
#  *     Distributed under the Boost Software License, Version 1.0. (See
#  *     accompanying file LICENSE_1_0.txt or copy at
#  *     http://www.boost.org/LICENSE_1_0.txt)
#  *                                                                          *
#  ************************************************************************** */
#
# /* See http://www.boost.org for most recent version. */
#
# if defined(MSGPACK_PP_ITERATION_LIMITS)
#    if !defined(MSGPACK_PP_FILENAME_5)
#        error MSGPACK_PP_ERROR:  depth #5 filename is not defined
#    endif
#    define MSGPACK_PP_VALUE MSGPACK_PP_TUPLE_ELEM(2, 0, MSGPACK_PP_ITERATION_LIMITS)
#    include <msgpack/preprocessor/iteration/detail/bounds/lower5.hpp>
#    define MSGPACK_PP_VALUE MSGPACK_PP_TUPLE_ELEM(2, 1, MSGPACK_PP_ITERATION_LIMITS)
#    include <msgpack/preprocessor/iteration/detail/bounds/upper5.hpp>
#    define MSGPACK_PP_ITERATION_FLAGS_5() 0
#    undef MSGPACK_PP_ITERATION_LIMITS
# elif defined(MSGPACK_PP_ITERATION_PARAMS_5)
#    define MSGPACK_PP_VALUE MSGPACK_PP_ARRAY_ELEM(0, MSGPACK_PP_ITERATION_PARAMS_5)
#    include <msgpack/preprocessor/iteration/detail/bounds/lower5.hpp>
#    define MSGPACK_PP_VALUE MSGPACK_PP_ARRAY_ELEM(1, MSGPACK_PP_ITERATION_PARAMS_5)
#    include <msgpack/preprocessor/iteration/detail/bounds/upper5.hpp>
#    define MSGPACK_PP_FILENAME_5 MSGPACK_PP_ARRAY_ELEM(2, MSGPACK_PP_ITERATION_PARAMS_5)
#    if MSGPACK_PP_ARRAY_SIZE(MSGPACK_PP_ITERATION_PARAMS_5) >= 4
#        define MSGPACK_PP_ITERATION_FLAGS_5() MSGPACK_PP_ARRAY_ELEM(3, MSGPACK_PP_ITERATION_PARAMS_5)
#    else
#        define MSGPACK_PP_ITERATION_FLAGS_5() 0
#    endif
# else
#    error MSGPACK_PP_ERROR:  depth #5 iteration boundaries or filename not defined
# endif
#
# undef MSGPACK_PP_ITERATION_DEPTH
# define MSGPACK_PP_ITERATION_DEPTH() 5
#
# if (MSGPACK_PP_ITERATION_START_5) > (MSGPACK_PP_ITERATION_FINISH_5)
#    include <msgpack/preprocessor/iteration/detail/iter/reverse5.hpp>
# else
#    if MSGPACK_PP_ITERATION_START_5 <= 0 && MSGPACK_PP_ITERATION_FINISH_5 >= 0
#        define MSGPACK_PP_ITERATION_5 0
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 1 && MSGPACK_PP_ITERATION_FINISH_5 >= 1
#        define MSGPACK_PP_ITERATION_5 1
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 2 && MSGPACK_PP_ITERATION_FINISH_5 >= 2
#        define MSGPACK_PP_ITERATION_5 2
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 3 && MSGPACK_PP_ITERATION_FINISH_5 >= 3
#        define MSGPACK_PP_ITERATION_5 3
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 4 && MSGPACK_PP_ITERATION_FINISH_5 >= 4
#        define MSGPACK_PP_ITERATION_5 4
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 5 && MSGPACK_PP_ITERATION_FINISH_5 >= 5
#        define MSGPACK_PP_ITERATION_5 5
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 6 && MSGPACK_PP_ITERATION_FINISH_5 >= 6
#        define MSGPACK_PP_ITERATION_5 6
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 7 && MSGPACK_PP_ITERATION_FINISH_5 >= 7
#        define MSGPACK_PP_ITERATION_5 7
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 8 && MSGPACK_PP_ITERATION_FINISH_5 >= 8
#        define MSGPACK_PP_ITERATION_5 8
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 9 && MSGPACK_PP_ITERATION_FINISH_5 >= 9
#        define MSGPACK_PP_ITERATION_5 9
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 10 && MSGPACK_PP_ITERATION_FINISH_5 >= 10
#        define MSGPACK_PP_ITERATION_5 10
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 11 && MSGPACK_PP_ITERATION_FINISH_5 >= 11
#        define MSGPACK_PP_ITERATION_5 11
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 12 && MSGPACK_PP_ITERATION_FINISH_5 >= 12
#        define MSGPACK_PP_ITERATION_5 12
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 13 && MSGPACK_PP_ITERATION_FINISH_5 >= 13
#        define MSGPACK_PP_ITERATION_5 13
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 14 && MSGPACK_PP_ITERATION_FINISH_5 >= 14
#        define MSGPACK_PP_ITERATION_5 14
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 15 && MSGPACK_PP_ITERATION_FINISH_5 >= 15
#        define MSGPACK_PP_ITERATION_5 15
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 16 && MSGPACK_PP_ITERATION_FINISH_5 >= 16
#        define MSGPACK_PP_ITERATION_5 16
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 17 && MSGPACK_PP_ITERATION_FINISH_5 >= 17
#        define MSGPACK_PP_ITERATION_5 17
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 18 && MSGPACK_PP_ITERATION_FINISH_5 >= 18
#        define MSGPACK_PP_ITERATION_5 18
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 19 && MSGPACK_PP_ITERATION_FINISH_5 >= 19
#        define MSGPACK_PP_ITERATION_5 19
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 20 && MSGPACK_PP_ITERATION_FINISH_5 >= 20
#        define MSGPACK_PP_ITERATION_5 20
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 21 && MSGPACK_PP_ITERATION_FINISH_5 >= 21
#        define MSGPACK_PP_ITERATION_5 21
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 22 && MSGPACK_PP_ITERATION_FINISH_5 >= 22
#        define MSGPACK_PP_ITERATION_5 22
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 23 && MSGPACK_PP_ITERATION_FINISH_5 >= 23
#        define MSGPACK_PP_ITERATION_5 23
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 24 && MSGPACK_PP_ITERATION_FINISH_5 >= 24
#        define MSGPACK_PP_ITERATION_5 24
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 25 && MSGPACK_PP_ITERATION_FINISH_5 >= 25
#        define MSGPACK_PP_ITERATION_5 25
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 26 && MSGPACK_PP_ITERATION_FINISH_5 >= 26
#        define MSGPACK_PP_ITERATION_5 26
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 27 && MSGPACK_PP_ITERATION_FINISH_5 >= 27
#        define MSGPACK_PP_ITERATION_5 27
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 28 && MSGPACK_PP_ITERATION_FINISH_5 >= 28
#        define MSGPACK_PP_ITERATION_5 28
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 29 && MSGPACK_PP_ITERATION_FINISH_5 >= 29
#        define MSGPACK_PP_ITERATION_5 29
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 30 && MSGPACK_PP_ITERATION_FINISH_5 >= 30
#        define MSGPACK_PP_ITERATION_5 30
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 31 && MSGPACK_PP_ITERATION_FINISH_5 >= 31
#        define MSGPACK_PP_ITERATION_5 31
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 32 && MSGPACK_PP_ITERATION_FINISH_5 >= 32
#        define MSGPACK_PP_ITERATION_5 32
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 33 && MSGPACK_PP_ITERATION_FINISH_5 >= 33
#        define MSGPACK_PP_ITERATION_5 33
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 34 && MSGPACK_PP_ITERATION_FINISH_5 >= 34
#        define MSGPACK_PP_ITERATION_5 34
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 35 && MSGPACK_PP_ITERATION_FINISH_5 >= 35
#        define MSGPACK_PP_ITERATION_5 35
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 36 && MSGPACK_PP_ITERATION_FINISH_5 >= 36
#        define MSGPACK_PP_ITERATION_5 36
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 37 && MSGPACK_PP_ITERATION_FINISH_5 >= 37
#        define MSGPACK_PP_ITERATION_5 37
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 38 && MSGPACK_PP_ITERATION_FINISH_5 >= 38
#        define MSGPACK_PP_ITERATION_5 38
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 39 && MSGPACK_PP_ITERATION_FINISH_5 >= 39
#        define MSGPACK_PP_ITERATION_5 39
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 40 && MSGPACK_PP_ITERATION_FINISH_5 >= 40
#        define MSGPACK_PP_ITERATION_5 40
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 41 && MSGPACK_PP_ITERATION_FINISH_5 >= 41
#        define MSGPACK_PP_ITERATION_5 41
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 42 && MSGPACK_PP_ITERATION_FINISH_5 >= 42
#        define MSGPACK_PP_ITERATION_5 42
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 43 && MSGPACK_PP_ITERATION_FINISH_5 >= 43
#        define MSGPACK_PP_ITERATION_5 43
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 44 && MSGPACK_PP_ITERATION_FINISH_5 >= 44
#        define MSGPACK_PP_ITERATION_5 44
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 45 && MSGPACK_PP_ITERATION_FINISH_5 >= 45
#        define MSGPACK_PP_ITERATION_5 45
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 46 && MSGPACK_PP_ITERATION_FINISH_5 >= 46
#        define MSGPACK_PP_ITERATION_5 46
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 47 && MSGPACK_PP_ITERATION_FINISH_5 >= 47
#        define MSGPACK_PP_ITERATION_5 47
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 48 && MSGPACK_PP_ITERATION_FINISH_5 >= 48
#        define MSGPACK_PP_ITERATION_5 48
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 49 && MSGPACK_PP_ITERATION_FINISH_5 >= 49
#        define MSGPACK_PP_ITERATION_5 49
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 50 && MSGPACK_PP_ITERATION_FINISH_5 >= 50
#        define MSGPACK_PP_ITERATION_5 50
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 51 && MSGPACK_PP_ITERATION_FINISH_5 >= 51
#        define MSGPACK_PP_ITERATION_5 51
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 52 && MSGPACK_PP_ITERATION_FINISH_5 >= 52
#        define MSGPACK_PP_ITERATION_5 52
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 53 && MSGPACK_PP_ITERATION_FINISH_5 >= 53
#        define MSGPACK_PP_ITERATION_5 53
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 54 && MSGPACK_PP_ITERATION_FINISH_5 >= 54
#        define MSGPACK_PP_ITERATION_5 54
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 55 && MSGPACK_PP_ITERATION_FINISH_5 >= 55
#        define MSGPACK_PP_ITERATION_5 55
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 56 && MSGPACK_PP_ITERATION_FINISH_5 >= 56
#        define MSGPACK_PP_ITERATION_5 56
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 57 && MSGPACK_PP_ITERATION_FINISH_5 >= 57
#        define MSGPACK_PP_ITERATION_5 57
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 58 && MSGPACK_PP_ITERATION_FINISH_5 >= 58
#        define MSGPACK_PP_ITERATION_5 58
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 59 && MSGPACK_PP_ITERATION_FINISH_5 >= 59
#        define MSGPACK_PP_ITERATION_5 59
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 60 && MSGPACK_PP_ITERATION_FINISH_5 >= 60
#        define MSGPACK_PP_ITERATION_5 60
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 61 && MSGPACK_PP_ITERATION_FINISH_5 >= 61
#        define MSGPACK_PP_ITERATION_5 61
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 62 && MSGPACK_PP_ITERATION_FINISH_5 >= 62
#        define MSGPACK_PP_ITERATION_5 62
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 63 && MSGPACK_PP_ITERATION_FINISH_5 >= 63
#        define MSGPACK_PP_ITERATION_5 63
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 64 && MSGPACK_PP_ITERATION_FINISH_5 >= 64
#        define MSGPACK_PP_ITERATION_5 64
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 65 && MSGPACK_PP_ITERATION_FINISH_5 >= 65
#        define MSGPACK_PP_ITERATION_5 65
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 66 && MSGPACK_PP_ITERATION_FINISH_5 >= 66
#        define MSGPACK_PP_ITERATION_5 66
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 67 && MSGPACK_PP_ITERATION_FINISH_5 >= 67
#        define MSGPACK_PP_ITERATION_5 67
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 68 && MSGPACK_PP_ITERATION_FINISH_5 >= 68
#        define MSGPACK_PP_ITERATION_5 68
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 69 && MSGPACK_PP_ITERATION_FINISH_5 >= 69
#        define MSGPACK_PP_ITERATION_5 69
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 70 && MSGPACK_PP_ITERATION_FINISH_5 >= 70
#        define MSGPACK_PP_ITERATION_5 70
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 71 && MSGPACK_PP_ITERATION_FINISH_5 >= 71
#        define MSGPACK_PP_ITERATION_5 71
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 72 && MSGPACK_PP_ITERATION_FINISH_5 >= 72
#        define MSGPACK_PP_ITERATION_5 72
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 73 && MSGPACK_PP_ITERATION_FINISH_5 >= 73
#        define MSGPACK_PP_ITERATION_5 73
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 74 && MSGPACK_PP_ITERATION_FINISH_5 >= 74
#        define MSGPACK_PP_ITERATION_5 74
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 75 && MSGPACK_PP_ITERATION_FINISH_5 >= 75
#        define MSGPACK_PP_ITERATION_5 75
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 76 && MSGPACK_PP_ITERATION_FINISH_5 >= 76
#        define MSGPACK_PP_ITERATION_5 76
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 77 && MSGPACK_PP_ITERATION_FINISH_5 >= 77
#        define MSGPACK_PP_ITERATION_5 77
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 78 && MSGPACK_PP_ITERATION_FINISH_5 >= 78
#        define MSGPACK_PP_ITERATION_5 78
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 79 && MSGPACK_PP_ITERATION_FINISH_5 >= 79
#        define MSGPACK_PP_ITERATION_5 79
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 80 && MSGPACK_PP_ITERATION_FINISH_5 >= 80
#        define MSGPACK_PP_ITERATION_5 80
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 81 && MSGPACK_PP_ITERATION_FINISH_5 >= 81
#        define MSGPACK_PP_ITERATION_5 81
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 82 && MSGPACK_PP_ITERATION_FINISH_5 >= 82
#        define MSGPACK_PP_ITERATION_5 82
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 83 && MSGPACK_PP_ITERATION_FINISH_5 >= 83
#        define MSGPACK_PP_ITERATION_5 83
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 84 && MSGPACK_PP_ITERATION_FINISH_5 >= 84
#        define MSGPACK_PP_ITERATION_5 84
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 85 && MSGPACK_PP_ITERATION_FINISH_5 >= 85
#        define MSGPACK_PP_ITERATION_5 85
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 86 && MSGPACK_PP_ITERATION_FINISH_5 >= 86
#        define MSGPACK_PP_ITERATION_5 86
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 87 && MSGPACK_PP_ITERATION_FINISH_5 >= 87
#        define MSGPACK_PP_ITERATION_5 87
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 88 && MSGPACK_PP_ITERATION_FINISH_5 >= 88
#        define MSGPACK_PP_ITERATION_5 88
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 89 && MSGPACK_PP_ITERATION_FINISH_5 >= 89
#        define MSGPACK_PP_ITERATION_5 89
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 90 && MSGPACK_PP_ITERATION_FINISH_5 >= 90
#        define MSGPACK_PP_ITERATION_5 90
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 91 && MSGPACK_PP_ITERATION_FINISH_5 >= 91
#        define MSGPACK_PP_ITERATION_5 91
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 92 && MSGPACK_PP_ITERATION_FINISH_5 >= 92
#        define MSGPACK_PP_ITERATION_5 92
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 93 && MSGPACK_PP_ITERATION_FINISH_5 >= 93
#        define MSGPACK_PP_ITERATION_5 93
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 94 && MSGPACK_PP_ITERATION_FINISH_5 >= 94
#        define MSGPACK_PP_ITERATION_5 94
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 95 && MSGPACK_PP_ITERATION_FINISH_5 >= 95
#        define MSGPACK_PP_ITERATION_5 95
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 96 && MSGPACK_PP_ITERATION_FINISH_5 >= 96
#        define MSGPACK_PP_ITERATION_5 96
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 97 && MSGPACK_PP_ITERATION_FINISH_5 >= 97
#        define MSGPACK_PP_ITERATION_5 97
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 98 && MSGPACK_PP_ITERATION_FINISH_5 >= 98
#        define MSGPACK_PP_ITERATION_5 98
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 99 && MSGPACK_PP_ITERATION_FINISH_5 >= 99
#        define MSGPACK_PP_ITERATION_5 99
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 100 && MSGPACK_PP_ITERATION_FINISH_5 >= 100
#        define MSGPACK_PP_ITERATION_5 100
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 101 && MSGPACK_PP_ITERATION_FINISH_5 >= 101
#        define MSGPACK_PP_ITERATION_5 101
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 102 && MSGPACK_PP_ITERATION_FINISH_5 >= 102
#        define MSGPACK_PP_ITERATION_5 102
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 103 && MSGPACK_PP_ITERATION_FINISH_5 >= 103
#        define MSGPACK_PP_ITERATION_5 103
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 104 && MSGPACK_PP_ITERATION_FINISH_5 >= 104
#        define MSGPACK_PP_ITERATION_5 104
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 105 && MSGPACK_PP_ITERATION_FINISH_5 >= 105
#        define MSGPACK_PP_ITERATION_5 105
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 106 && MSGPACK_PP_ITERATION_FINISH_5 >= 106
#        define MSGPACK_PP_ITERATION_5 106
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 107 && MSGPACK_PP_ITERATION_FINISH_5 >= 107
#        define MSGPACK_PP_ITERATION_5 107
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 108 && MSGPACK_PP_ITERATION_FINISH_5 >= 108
#        define MSGPACK_PP_ITERATION_5 108
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 109 && MSGPACK_PP_ITERATION_FINISH_5 >= 109
#        define MSGPACK_PP_ITERATION_5 109
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 110 && MSGPACK_PP_ITERATION_FINISH_5 >= 110
#        define MSGPACK_PP_ITERATION_5 110
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 111 && MSGPACK_PP_ITERATION_FINISH_5 >= 111
#        define MSGPACK_PP_ITERATION_5 111
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 112 && MSGPACK_PP_ITERATION_FINISH_5 >= 112
#        define MSGPACK_PP_ITERATION_5 112
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 113 && MSGPACK_PP_ITERATION_FINISH_5 >= 113
#        define MSGPACK_PP_ITERATION_5 113
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 114 && MSGPACK_PP_ITERATION_FINISH_5 >= 114
#        define MSGPACK_PP_ITERATION_5 114
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 115 && MSGPACK_PP_ITERATION_FINISH_5 >= 115
#        define MSGPACK_PP_ITERATION_5 115
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 116 && MSGPACK_PP_ITERATION_FINISH_5 >= 116
#        define MSGPACK_PP_ITERATION_5 116
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 117 && MSGPACK_PP_ITERATION_FINISH_5 >= 117
#        define MSGPACK_PP_ITERATION_5 117
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 118 && MSGPACK_PP_ITERATION_FINISH_5 >= 118
#        define MSGPACK_PP_ITERATION_5 118
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 119 && MSGPACK_PP_ITERATION_FINISH_5 >= 119
#        define MSGPACK_PP_ITERATION_5 119
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 120 && MSGPACK_PP_ITERATION_FINISH_5 >= 120
#        define MSGPACK_PP_ITERATION_5 120
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 121 && MSGPACK_PP_ITERATION_FINISH_5 >= 121
#        define MSGPACK_PP_ITERATION_5 121
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 122 && MSGPACK_PP_ITERATION_FINISH_5 >= 122
#        define MSGPACK_PP_ITERATION_5 122
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 123 && MSGPACK_PP_ITERATION_FINISH_5 >= 123
#        define MSGPACK_PP_ITERATION_5 123
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 124 && MSGPACK_PP_ITERATION_FINISH_5 >= 124
#        define MSGPACK_PP_ITERATION_5 124
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 125 && MSGPACK_PP_ITERATION_FINISH_5 >= 125
#        define MSGPACK_PP_ITERATION_5 125
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 126 && MSGPACK_PP_ITERATION_FINISH_5 >= 126
#        define MSGPACK_PP_ITERATION_5 126
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 127 && MSGPACK_PP_ITERATION_FINISH_5 >= 127
#        define MSGPACK_PP_ITERATION_5 127
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 128 && MSGPACK_PP_ITERATION_FINISH_5 >= 128
#        define MSGPACK_PP_ITERATION_5 128
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 129 && MSGPACK_PP_ITERATION_FINISH_5 >= 129
#        define MSGPACK_PP_ITERATION_5 129
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 130 && MSGPACK_PP_ITERATION_FINISH_5 >= 130
#        define MSGPACK_PP_ITERATION_5 130
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 131 && MSGPACK_PP_ITERATION_FINISH_5 >= 131
#        define MSGPACK_PP_ITERATION_5 131
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 132 && MSGPACK_PP_ITERATION_FINISH_5 >= 132
#        define MSGPACK_PP_ITERATION_5 132
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 133 && MSGPACK_PP_ITERATION_FINISH_5 >= 133
#        define MSGPACK_PP_ITERATION_5 133
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 134 && MSGPACK_PP_ITERATION_FINISH_5 >= 134
#        define MSGPACK_PP_ITERATION_5 134
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 135 && MSGPACK_PP_ITERATION_FINISH_5 >= 135
#        define MSGPACK_PP_ITERATION_5 135
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 136 && MSGPACK_PP_ITERATION_FINISH_5 >= 136
#        define MSGPACK_PP_ITERATION_5 136
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 137 && MSGPACK_PP_ITERATION_FINISH_5 >= 137
#        define MSGPACK_PP_ITERATION_5 137
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 138 && MSGPACK_PP_ITERATION_FINISH_5 >= 138
#        define MSGPACK_PP_ITERATION_5 138
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 139 && MSGPACK_PP_ITERATION_FINISH_5 >= 139
#        define MSGPACK_PP_ITERATION_5 139
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 140 && MSGPACK_PP_ITERATION_FINISH_5 >= 140
#        define MSGPACK_PP_ITERATION_5 140
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 141 && MSGPACK_PP_ITERATION_FINISH_5 >= 141
#        define MSGPACK_PP_ITERATION_5 141
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 142 && MSGPACK_PP_ITERATION_FINISH_5 >= 142
#        define MSGPACK_PP_ITERATION_5 142
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 143 && MSGPACK_PP_ITERATION_FINISH_5 >= 143
#        define MSGPACK_PP_ITERATION_5 143
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 144 && MSGPACK_PP_ITERATION_FINISH_5 >= 144
#        define MSGPACK_PP_ITERATION_5 144
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 145 && MSGPACK_PP_ITERATION_FINISH_5 >= 145
#        define MSGPACK_PP_ITERATION_5 145
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 146 && MSGPACK_PP_ITERATION_FINISH_5 >= 146
#        define MSGPACK_PP_ITERATION_5 146
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 147 && MSGPACK_PP_ITERATION_FINISH_5 >= 147
#        define MSGPACK_PP_ITERATION_5 147
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 148 && MSGPACK_PP_ITERATION_FINISH_5 >= 148
#        define MSGPACK_PP_ITERATION_5 148
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 149 && MSGPACK_PP_ITERATION_FINISH_5 >= 149
#        define MSGPACK_PP_ITERATION_5 149
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 150 && MSGPACK_PP_ITERATION_FINISH_5 >= 150
#        define MSGPACK_PP_ITERATION_5 150
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 151 && MSGPACK_PP_ITERATION_FINISH_5 >= 151
#        define MSGPACK_PP_ITERATION_5 151
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 152 && MSGPACK_PP_ITERATION_FINISH_5 >= 152
#        define MSGPACK_PP_ITERATION_5 152
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 153 && MSGPACK_PP_ITERATION_FINISH_5 >= 153
#        define MSGPACK_PP_ITERATION_5 153
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 154 && MSGPACK_PP_ITERATION_FINISH_5 >= 154
#        define MSGPACK_PP_ITERATION_5 154
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 155 && MSGPACK_PP_ITERATION_FINISH_5 >= 155
#        define MSGPACK_PP_ITERATION_5 155
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 156 && MSGPACK_PP_ITERATION_FINISH_5 >= 156
#        define MSGPACK_PP_ITERATION_5 156
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 157 && MSGPACK_PP_ITERATION_FINISH_5 >= 157
#        define MSGPACK_PP_ITERATION_5 157
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 158 && MSGPACK_PP_ITERATION_FINISH_5 >= 158
#        define MSGPACK_PP_ITERATION_5 158
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 159 && MSGPACK_PP_ITERATION_FINISH_5 >= 159
#        define MSGPACK_PP_ITERATION_5 159
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 160 && MSGPACK_PP_ITERATION_FINISH_5 >= 160
#        define MSGPACK_PP_ITERATION_5 160
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 161 && MSGPACK_PP_ITERATION_FINISH_5 >= 161
#        define MSGPACK_PP_ITERATION_5 161
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 162 && MSGPACK_PP_ITERATION_FINISH_5 >= 162
#        define MSGPACK_PP_ITERATION_5 162
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 163 && MSGPACK_PP_ITERATION_FINISH_5 >= 163
#        define MSGPACK_PP_ITERATION_5 163
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 164 && MSGPACK_PP_ITERATION_FINISH_5 >= 164
#        define MSGPACK_PP_ITERATION_5 164
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 165 && MSGPACK_PP_ITERATION_FINISH_5 >= 165
#        define MSGPACK_PP_ITERATION_5 165
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 166 && MSGPACK_PP_ITERATION_FINISH_5 >= 166
#        define MSGPACK_PP_ITERATION_5 166
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 167 && MSGPACK_PP_ITERATION_FINISH_5 >= 167
#        define MSGPACK_PP_ITERATION_5 167
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 168 && MSGPACK_PP_ITERATION_FINISH_5 >= 168
#        define MSGPACK_PP_ITERATION_5 168
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 169 && MSGPACK_PP_ITERATION_FINISH_5 >= 169
#        define MSGPACK_PP_ITERATION_5 169
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 170 && MSGPACK_PP_ITERATION_FINISH_5 >= 170
#        define MSGPACK_PP_ITERATION_5 170
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 171 && MSGPACK_PP_ITERATION_FINISH_5 >= 171
#        define MSGPACK_PP_ITERATION_5 171
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 172 && MSGPACK_PP_ITERATION_FINISH_5 >= 172
#        define MSGPACK_PP_ITERATION_5 172
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 173 && MSGPACK_PP_ITERATION_FINISH_5 >= 173
#        define MSGPACK_PP_ITERATION_5 173
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 174 && MSGPACK_PP_ITERATION_FINISH_5 >= 174
#        define MSGPACK_PP_ITERATION_5 174
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 175 && MSGPACK_PP_ITERATION_FINISH_5 >= 175
#        define MSGPACK_PP_ITERATION_5 175
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 176 && MSGPACK_PP_ITERATION_FINISH_5 >= 176
#        define MSGPACK_PP_ITERATION_5 176
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 177 && MSGPACK_PP_ITERATION_FINISH_5 >= 177
#        define MSGPACK_PP_ITERATION_5 177
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 178 && MSGPACK_PP_ITERATION_FINISH_5 >= 178
#        define MSGPACK_PP_ITERATION_5 178
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 179 && MSGPACK_PP_ITERATION_FINISH_5 >= 179
#        define MSGPACK_PP_ITERATION_5 179
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 180 && MSGPACK_PP_ITERATION_FINISH_5 >= 180
#        define MSGPACK_PP_ITERATION_5 180
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 181 && MSGPACK_PP_ITERATION_FINISH_5 >= 181
#        define MSGPACK_PP_ITERATION_5 181
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 182 && MSGPACK_PP_ITERATION_FINISH_5 >= 182
#        define MSGPACK_PP_ITERATION_5 182
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 183 && MSGPACK_PP_ITERATION_FINISH_5 >= 183
#        define MSGPACK_PP_ITERATION_5 183
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 184 && MSGPACK_PP_ITERATION_FINISH_5 >= 184
#        define MSGPACK_PP_ITERATION_5 184
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 185 && MSGPACK_PP_ITERATION_FINISH_5 >= 185
#        define MSGPACK_PP_ITERATION_5 185
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 186 && MSGPACK_PP_ITERATION_FINISH_5 >= 186
#        define MSGPACK_PP_ITERATION_5 186
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 187 && MSGPACK_PP_ITERATION_FINISH_5 >= 187
#        define MSGPACK_PP_ITERATION_5 187
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 188 && MSGPACK_PP_ITERATION_FINISH_5 >= 188
#        define MSGPACK_PP_ITERATION_5 188
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 189 && MSGPACK_PP_ITERATION_FINISH_5 >= 189
#        define MSGPACK_PP_ITERATION_5 189
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 190 && MSGPACK_PP_ITERATION_FINISH_5 >= 190
#        define MSGPACK_PP_ITERATION_5 190
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 191 && MSGPACK_PP_ITERATION_FINISH_5 >= 191
#        define MSGPACK_PP_ITERATION_5 191
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 192 && MSGPACK_PP_ITERATION_FINISH_5 >= 192
#        define MSGPACK_PP_ITERATION_5 192
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 193 && MSGPACK_PP_ITERATION_FINISH_5 >= 193
#        define MSGPACK_PP_ITERATION_5 193
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 194 && MSGPACK_PP_ITERATION_FINISH_5 >= 194
#        define MSGPACK_PP_ITERATION_5 194
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 195 && MSGPACK_PP_ITERATION_FINISH_5 >= 195
#        define MSGPACK_PP_ITERATION_5 195
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 196 && MSGPACK_PP_ITERATION_FINISH_5 >= 196
#        define MSGPACK_PP_ITERATION_5 196
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 197 && MSGPACK_PP_ITERATION_FINISH_5 >= 197
#        define MSGPACK_PP_ITERATION_5 197
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 198 && MSGPACK_PP_ITERATION_FINISH_5 >= 198
#        define MSGPACK_PP_ITERATION_5 198
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 199 && MSGPACK_PP_ITERATION_FINISH_5 >= 199
#        define MSGPACK_PP_ITERATION_5 199
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 200 && MSGPACK_PP_ITERATION_FINISH_5 >= 200
#        define MSGPACK_PP_ITERATION_5 200
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 201 && MSGPACK_PP_ITERATION_FINISH_5 >= 201
#        define MSGPACK_PP_ITERATION_5 201
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 202 && MSGPACK_PP_ITERATION_FINISH_5 >= 202
#        define MSGPACK_PP_ITERATION_5 202
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 203 && MSGPACK_PP_ITERATION_FINISH_5 >= 203
#        define MSGPACK_PP_ITERATION_5 203
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 204 && MSGPACK_PP_ITERATION_FINISH_5 >= 204
#        define MSGPACK_PP_ITERATION_5 204
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 205 && MSGPACK_PP_ITERATION_FINISH_5 >= 205
#        define MSGPACK_PP_ITERATION_5 205
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 206 && MSGPACK_PP_ITERATION_FINISH_5 >= 206
#        define MSGPACK_PP_ITERATION_5 206
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 207 && MSGPACK_PP_ITERATION_FINISH_5 >= 207
#        define MSGPACK_PP_ITERATION_5 207
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 208 && MSGPACK_PP_ITERATION_FINISH_5 >= 208
#        define MSGPACK_PP_ITERATION_5 208
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 209 && MSGPACK_PP_ITERATION_FINISH_5 >= 209
#        define MSGPACK_PP_ITERATION_5 209
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 210 && MSGPACK_PP_ITERATION_FINISH_5 >= 210
#        define MSGPACK_PP_ITERATION_5 210
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 211 && MSGPACK_PP_ITERATION_FINISH_5 >= 211
#        define MSGPACK_PP_ITERATION_5 211
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 212 && MSGPACK_PP_ITERATION_FINISH_5 >= 212
#        define MSGPACK_PP_ITERATION_5 212
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 213 && MSGPACK_PP_ITERATION_FINISH_5 >= 213
#        define MSGPACK_PP_ITERATION_5 213
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 214 && MSGPACK_PP_ITERATION_FINISH_5 >= 214
#        define MSGPACK_PP_ITERATION_5 214
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 215 && MSGPACK_PP_ITERATION_FINISH_5 >= 215
#        define MSGPACK_PP_ITERATION_5 215
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 216 && MSGPACK_PP_ITERATION_FINISH_5 >= 216
#        define MSGPACK_PP_ITERATION_5 216
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 217 && MSGPACK_PP_ITERATION_FINISH_5 >= 217
#        define MSGPACK_PP_ITERATION_5 217
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 218 && MSGPACK_PP_ITERATION_FINISH_5 >= 218
#        define MSGPACK_PP_ITERATION_5 218
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 219 && MSGPACK_PP_ITERATION_FINISH_5 >= 219
#        define MSGPACK_PP_ITERATION_5 219
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 220 && MSGPACK_PP_ITERATION_FINISH_5 >= 220
#        define MSGPACK_PP_ITERATION_5 220
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 221 && MSGPACK_PP_ITERATION_FINISH_5 >= 221
#        define MSGPACK_PP_ITERATION_5 221
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 222 && MSGPACK_PP_ITERATION_FINISH_5 >= 222
#        define MSGPACK_PP_ITERATION_5 222
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 223 && MSGPACK_PP_ITERATION_FINISH_5 >= 223
#        define MSGPACK_PP_ITERATION_5 223
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 224 && MSGPACK_PP_ITERATION_FINISH_5 >= 224
#        define MSGPACK_PP_ITERATION_5 224
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 225 && MSGPACK_PP_ITERATION_FINISH_5 >= 225
#        define MSGPACK_PP_ITERATION_5 225
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 226 && MSGPACK_PP_ITERATION_FINISH_5 >= 226
#        define MSGPACK_PP_ITERATION_5 226
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 227 && MSGPACK_PP_ITERATION_FINISH_5 >= 227
#        define MSGPACK_PP_ITERATION_5 227
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 228 && MSGPACK_PP_ITERATION_FINISH_5 >= 228
#        define MSGPACK_PP_ITERATION_5 228
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 229 && MSGPACK_PP_ITERATION_FINISH_5 >= 229
#        define MSGPACK_PP_ITERATION_5 229
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 230 && MSGPACK_PP_ITERATION_FINISH_5 >= 230
#        define MSGPACK_PP_ITERATION_5 230
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 231 && MSGPACK_PP_ITERATION_FINISH_5 >= 231
#        define MSGPACK_PP_ITERATION_5 231
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 232 && MSGPACK_PP_ITERATION_FINISH_5 >= 232
#        define MSGPACK_PP_ITERATION_5 232
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 233 && MSGPACK_PP_ITERATION_FINISH_5 >= 233
#        define MSGPACK_PP_ITERATION_5 233
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 234 && MSGPACK_PP_ITERATION_FINISH_5 >= 234
#        define MSGPACK_PP_ITERATION_5 234
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 235 && MSGPACK_PP_ITERATION_FINISH_5 >= 235
#        define MSGPACK_PP_ITERATION_5 235
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 236 && MSGPACK_PP_ITERATION_FINISH_5 >= 236
#        define MSGPACK_PP_ITERATION_5 236
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 237 && MSGPACK_PP_ITERATION_FINISH_5 >= 237
#        define MSGPACK_PP_ITERATION_5 237
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 238 && MSGPACK_PP_ITERATION_FINISH_5 >= 238
#        define MSGPACK_PP_ITERATION_5 238
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 239 && MSGPACK_PP_ITERATION_FINISH_5 >= 239
#        define MSGPACK_PP_ITERATION_5 239
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 240 && MSGPACK_PP_ITERATION_FINISH_5 >= 240
#        define MSGPACK_PP_ITERATION_5 240
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 241 && MSGPACK_PP_ITERATION_FINISH_5 >= 241
#        define MSGPACK_PP_ITERATION_5 241
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 242 && MSGPACK_PP_ITERATION_FINISH_5 >= 242
#        define MSGPACK_PP_ITERATION_5 242
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 243 && MSGPACK_PP_ITERATION_FINISH_5 >= 243
#        define MSGPACK_PP_ITERATION_5 243
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 244 && MSGPACK_PP_ITERATION_FINISH_5 >= 244
#        define MSGPACK_PP_ITERATION_5 244
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 245 && MSGPACK_PP_ITERATION_FINISH_5 >= 245
#        define MSGPACK_PP_ITERATION_5 245
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 246 && MSGPACK_PP_ITERATION_FINISH_5 >= 246
#        define MSGPACK_PP_ITERATION_5 246
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 247 && MSGPACK_PP_ITERATION_FINISH_5 >= 247
#        define MSGPACK_PP_ITERATION_5 247
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 248 && MSGPACK_PP_ITERATION_FINISH_5 >= 248
#        define MSGPACK_PP_ITERATION_5 248
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 249 && MSGPACK_PP_ITERATION_FINISH_5 >= 249
#        define MSGPACK_PP_ITERATION_5 249
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 250 && MSGPACK_PP_ITERATION_FINISH_5 >= 250
#        define MSGPACK_PP_ITERATION_5 250
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 251 && MSGPACK_PP_ITERATION_FINISH_5 >= 251
#        define MSGPACK_PP_ITERATION_5 251
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 252 && MSGPACK_PP_ITERATION_FINISH_5 >= 252
#        define MSGPACK_PP_ITERATION_5 252
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 253 && MSGPACK_PP_ITERATION_FINISH_5 >= 253
#        define MSGPACK_PP_ITERATION_5 253
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 254 && MSGPACK_PP_ITERATION_FINISH_5 >= 254
#        define MSGPACK_PP_ITERATION_5 254
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 255 && MSGPACK_PP_ITERATION_FINISH_5 >= 255
#        define MSGPACK_PP_ITERATION_5 255
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
#    if MSGPACK_PP_ITERATION_START_5 <= 256 && MSGPACK_PP_ITERATION_FINISH_5 >= 256
#        define MSGPACK_PP_ITERATION_5 256
#        include MSGPACK_PP_FILENAME_5
#        undef MSGPACK_PP_ITERATION_5
#    endif
# endif
#
# undef MSGPACK_PP_ITERATION_DEPTH
# define MSGPACK_PP_ITERATION_DEPTH() 4
#
# undef MSGPACK_PP_ITERATION_START_5
# undef MSGPACK_PP_ITERATION_FINISH_5
# undef MSGPACK_PP_FILENAME_5
#
# undef MSGPACK_PP_ITERATION_FLAGS_5
# undef MSGPACK_PP_ITERATION_PARAMS_5
